@@ -71,6 +71,7 @@ def run(
     if not gor_query:
         click.secho("Specify --query or --queryfile", fg='red')
         return
+    qry = None
     try:
         qry = svc.execute(gor_query, relations=prepared_relations, job_type=job_type, nowait=True)
         click.secho(
@@ -86,11 +87,12 @@ def run(
         click.echo(txt)
         return
     except KeyboardInterrupt:
-        try:
-            qry.cancel()
-        except QueryError:
-            pass
-        abort("Query {} has been cancelled".format(qry.query_id))
+        if qry:
+            try:
+                qry.cancel()
+            except QueryError:
+                pass
+            abort("Query {} has been cancelled".format(qry.query_id))
         return None
 
     if qry.failed:
